@@ -199,6 +199,11 @@ void AnalitzaTest::testTrivialEvaluate_data()
 	QTest::newRow("filter") << "filter(x->x>5, list {3,4,5,6,7})" << "list { 6, 7 }";
 	
 	QTest::newRow("forall1") << "forall(a<w:a@list { 2 })" << "2<w";
+	
+	QTest::newRow("matrix") << "matrix { matrixrow { 1, 2 } }" << "matrix { matrixrow { 1, 2 } }";
+	QTest::newRow("matrix+") << "matrix { matrixrow { 1, 2 } }+matrix{ matrixrow { 1, 2 } }" << "matrix { matrixrow { 2, 4 } }";
+	QTest::newRow("matrix@") << "selector(1, matrix { matrixrow { 1, 2 } })" << "vector { 1, 2 }";
+	QTest::newRow("matrix@@") << "selector(1, selector(1, matrix { matrixrow { 1, 2 } }))" << "1";
 }
 
 void AnalitzaTest::testTrivialEvaluate()
@@ -611,6 +616,8 @@ void AnalitzaTest::testSimplify_data()
 	QTest::newRow("mono1") << "2*y+y" << "3*y";
 	QTest::newRow("mono2") << "-y+1" << "-y+1";
 	
+	QTest::newRow("matrix") << "matrix { matrixrow { x, y, z } }" << "matrix { matrixrow { x, y, z } }";
+	
 	//equations
 	QTest::newRow("eqminus") << "x-3=0" << "x=3";
 	QTest::newRow("eqplus") << "x+3=0" << "x=-3";
